
#contact-form .controls .row label, 
#contact-form .controls .row input:not([type='submit']):not([name="captcha_1"]),
#contact-form .controls .row textarea {
    width: 100%;
}

#contact-form .btn-send {
    margin: 10px 0;
}

#contact-form .row {
    width: 80%;
    margin: 0 auto;
}