{% load i18n %}
<html>
    <head>
        <style>
            .wrapper {
                line-height: 2;
                padding: 20px;
            }

            .mail-button {
                background-color: #4CAF50;
                border: none;
                color: white;
                padding: 0 10px;
                text-align: center;
                text-decoration: none;
                display: inline-block;
                font-size: 16px;
            }
        </style>
    </head>
    <body>
        <div class="wrapper">
            <div>   
               {% blocktrans %}A contact form has been filled out on {{website_url}}, please find the form contents below.{% endblocktrans %}
            </div>
            <div>
                {% trans 'Name' %} : {{ form_data.name }}
            </div>
            <div>
                {% trans 'Email address' %} : {{ form_data.email_from }} <a class="mail-button" href="mailto:{{form_data.email_from}}">{% trans 'Reply' %}</a>
            </div>
            <div>
                {% trans 'Phone number' %} : {{ form_data.phonenumber }}
            </div>
            <div>
                {% trans 'Message' %} : {{ form_data.message|linebreaks }}
            </div>
        </div>
    </body>
</html>
