{% extends "layout.html" %}
{% load i18n %}

{% block content %}
    <div class="container">
        <div class="d-flex flex-column align-items-center my-5">
            
            <h1 class="font-weight-bold">{% trans 'Thank you!' %}</h1>
            
            <i class="fa fa-check text-success my-3" style="font-size: 50pt;"></i>
            
            <p>{% trans 'Thanks for your message! We will respond as soon as possible.' %}</p>
            
        </div>
    </div>
{% endblock %}
