# pylint: disable= E0632
from django.urls import path

from ocyan.main.loading import get_ocyan_class

from .constants import APP_CODE

post_contact_form = get_ocyan_class("contact_form.views", "post_contact_form")
ContactFormThankYou = get_ocyan_class("contact_form.views", "ContactFormThankYou")


app_name = APP_CODE
urlpatterns = [
    path("contact-form/", post_contact_form, name="contact-form-handler"),
    path(
        "contact-form/thank-you/",
        ContactFormThankYou.as_view(),
        name="contact-form-thank-you",
    ),
]
