{% extends 'oscar/layout.html' %}
{% load static %}

{% block extrastyles %}
    {{block.super}}
    <link href="{% static 'contact_form/css/styles.css' %}" type="text/css" rel="stylesheet" />
{% endblock %}