# -*- coding: utf-8 -*-
from pathlib import Path

from setuptools import find_packages, setup

install_requires: list = [
    "ocyan.core",
    "ocyan.plugin.wagtail",
    "ocyan.plugin.wagtail_content_page",
    "ocyan.plugin.google",
    "django-recaptcha",
    "django-phonenumber-field",
]

extras_require: dict = {
    "test": [
        "ocyan.plugin.testing",
        "wheel",
        "empty_testproject",
        "pylint-django",
        "black",
        "vdt.versionplugin.wheel",
        "coverage",
        "ocyan.plugin.coyote",
    ]
}

PACKAGE_CLASSIFIERS = [
    "Framework :: Ocyan",
    "Environment :: Plugins",
]

README = Path(__file__).with_name("README.md").read_text(encoding="utf-8")

setup(
    name="ocyan.plugin.contact_form",
    version="0.2.1",
    url="https://git.mandelblog.com/mandel-plugins/ocyan.plugin.contact_form",
    author="Motolani Olaiya",
    author_email="motolaniolaiya@gmail.com",
    description=(
        "Create contact forms on any page with reCAPTCHA from the google plugin,"
        " for spam protection."
    ),
    long_description=README,
    long_description_content_type="text/markdown",
    license="Proprietary",
    packages=find_packages(),
    include_package_data=True,
    python_requires=">=3.10",
    install_requires=install_requires,
    classifiers=PACKAGE_CLASSIFIERS,
    extras_require=extras_require,
)
